@@ -2,18 +2,8 @@
 from __future__ import unicode_literals
 
 from django.db import migrations, models
-
-def moveErrorMessages(apps, schema_editor):
-    ErrorMessageOld = apps.get_model("newsletter_extension", "ErrorMessage")
-    ErrorMessageNew = apps.get_model("cloud", "ErrorMessage")
-    for msg in ErrorMessageOld.objects.all():
-        ErrorMessageNew.objects.create(
-            id=msg.id,
-            message=msg.message,
-            contact=msg.contact,
-            newsletter=msg.newsletter
-        )
-
+# 因為之前 migrate 會出現錯誤，詳情請見 
+# https://code.nuwainfo.com/trac/mercurius/ticket/3220#comment:44
 class Migration(migrations.Migration):
 
     dependencies = [
@@ -21,7 +11,6 @@ class Migration(migrations.Migration):
     ]
 
     operations = [
-        #migrations.RunPython(moveErrorMessages),
         migrations.RemoveField(
             model_name='errormessage',
             name='contact',
