@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 10872 2018-03-18 16:15:33Z David $
+# $Id: models.py 12823 2021-03-31 12:51:48Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-19 01:15:33 +0900 (週一, 19 三月 2018) $
-# $Revision: 10872 $
+# $Author: Lavender $
+# $Date: 2021-03-31 20:51:48 +0800 (週三, 31 三月 2021) $
+# $Revision: 12823 $
 
 from emencia.django.newsletter.models import Newsletter, Contact
 
@@ -56,4 +56,15 @@ class Footer(models.Model):
 from emencia.django.newsletter.utils import newsletter
 from Theophrastus.Utility import trackLinks
 
-newsletter.track_links = trackLinks
\ No newline at end of file
+newsletter.track_links = trackLinks
+
+class BlackContact(models.Model):
+    email = models.EmailField(_('Email'), unique=True, db_index=True)
+    reason = models.TextField(_('Reason'))
+    createdTime = models.DateTimeField(_('Created time'), auto_now_add=False)
+    source = models.CharField(_('Source'), max_length=255, null=True)
+    mail = models.CharField(_('Mail'), max_length=255, null=True)
+    
+    class Meta:
+        verbose_name = _('BlackContact')
+        verbose_name_plural = _('BlackContact')
\ No newline at end of file
